Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: third_party/WebKit/Source/core/css/SelectorChecker.cpp

Issue 1675163002: Rename ComposedTree to FlatTree (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: wip Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/css/SelectorChecker.cpp
diff --git a/third_party/WebKit/Source/core/css/SelectorChecker.cpp b/third_party/WebKit/Source/core/css/SelectorChecker.cpp
index 771468302c6177825cb2a1575bbdfb6f0a2807ac..22d4d5fee6a7b26a4c0dc835ffb8cade1dbe836d 100644
--- a/third_party/WebKit/Source/core/css/SelectorChecker.cpp
+++ b/third_party/WebKit/Source/core/css/SelectorChecker.cpp
@@ -37,7 +37,7 @@
#include "core/dom/NthIndexCache.h"
#include "core/dom/StyleEngine.h"
#include "core/dom/Text.h"
-#include "core/dom/shadow/ComposedTreeTraversal.h"
+#include "core/dom/shadow/FlatTreeTraversal.h"
#include "core/dom/shadow/InsertionPoint.h"
#include "core/dom/shadow/ShadowRoot.h"
#include "core/editing/FrameSelection.h"
@@ -1073,7 +1073,7 @@ bool SelectorChecker::checkPseudoHost(const SelectorCheckingContext& context, Ma
for (subContext.selector = selector.selectorList()->first(); subContext.selector; subContext.selector = CSSSelectorList::next(*subContext.selector)) {
subContext.treatShadowHostAsNormalScope = true;
subContext.scope = context.scope;
// Use ComposedTreeTraversal to traverse a composed ancestor list of a given element.
Element* nextElement = &element;
SelectorCheckingContext hostContext(subContext);
do {
@@ -1092,7 +1092,7 @@ bool SelectorChecker::checkPseudoHost(const SelectorCheckingContext& context, Ma
break;
hostContext.inRightmostCompound = false;
- nextElement = ComposedTreeTraversal::parentElement(*nextElement);
+ nextElement = FlatTreeTraversal::parentElement(*nextElement);
} while (nextElement);
}
if (matched) {
@@ -1073,7 +1073,7 @@ bool SelectorChecker::checkPseudoHost(const SelectorCheckingContext& context, Ma
subContext.treatShadowHostAsNormalScope = true;
subContext.scope = context.scope;
- // Use ComposedTreeTraversal to traverse a composed ancestor list of a given element.
+ // Use FlatTreeTraversal to traverse a composed ancestor list of a given element.
Element* nextElement = &element;
SelectorCheckingContext hostContext(subContext);

Powered by Google App Engine
This is Rietveld 408576698